@@ -23,6 +23,8 @@
 
 #include "netinfo.h"
 
+#define SCAN_FORMAT "%d %s %s"
+
 typedef struct _scan_data scan_data;
 	
 struct _scan_data {
@@ -33,4 +35,7 @@ struct _scan_data {
 
 /* Scan funtions */
 void scan_do (Netinfo * netinfo);
+void scan_stop (Netinfo * netinfo);
+void scan_foreach (Netinfo * netinfo, gchar * line, gint len, gpointer user_data);
 void scan_define_model (Netinfo * netinfo, scan_data data);
+void scan_copy_to_clipboard (Netinfo * netinfo, gpointer user_data);
